# Guru-PK MCP 专家辩论系统

基于MCP（Model Context Protocol）的AI专家辩论系统，让不同领域的思想家围绕您的问题进行多轮智慧碰撞。

## ✨ 核心特色

- 🎭 **13位内置专家** - 涵盖哲学、商业、科学、战略等领域
- 🔄 **4轮PK流程** - 独立思考 → 交叉辩论 → 最终立场 → 智慧综合  
- 🛠️ **自定义专家** - 创建专属思想家角色
- 📊 **智能推荐** - 自动推荐最适合的专家组合
- 📚 **会话管理** - 本地保存，支持导出和恢复

## 🚀 快速安装

### 1. 安装依赖
```bash
curl -LsSf https://astral.sh/uv/install.sh | sh
```

### 2. 配置MCP客户端

**推荐方式：从PyPI安装**
```json
{
  "mcpServers": {
    "guru-pk": {
      "command": "uvx",
      "args": ["--from", "guru-pk-mcp", "guru-pk-mcp-server"],
      "env": {
        "DATA_DIR": "~/.guru-pk-data"
      }
    }
  }
}
```

> **注意**: macOS用户可能需要使用完整路径：`/Users/{用户名}/.local/bin/uvx`

**开发方式：从源码安装**
```json
{
  "mcpServers": {
    "guru-pk": {
      "command": "uvx", 
      "args": ["--from", "/path/to/guru-pk-mcp", "guru-pk-mcp-server"],
      "env": {
        "DATA_DIR": "~/.guru-pk-data"
      }
    }
  }
}
```

### 3. 开始使用
重启MCP客户端，输入 `guru_pk_help` 获取帮助，或直接提问开始专家辩论！

## 🎭 专家阵容

### 哲学思辨
🧠 **苏格拉底** - 批判思维，质疑表面答案  
☯️ **王阳明** - 心学大师，知行合一  
🧘 **克里希那穆提** - 觉察智慧，当下哲学  

### 商业创新  
🚀 **埃隆·马斯克** - 第一性原理，颠覆创新  
📚 **查理·芒格** - 多元思维，投资智慧  
🍎 **史蒂夫·乔布斯** - 产品完美主义，用户体验  
🌸 **稻盛和夫** - 敬天爱人，经营哲学  

### 经济战略
💰 **冯·米塞斯** - 奥地利学派，人类行动学  
⚔️ **孙子** - 兵学圣祖，战略思维  
📖 **曾国藩** - 修身治国，渐进改良  

### 科学方法
🔬 **卡尔·波普尔** - 可证伪性，批判理性主义  
🔄 **杰伊·福雷斯特** - 系统动力学，反馈环理论  
🧠 **大卫·伯恩斯** - CBT心理学，认知重构  

## 💡 使用方法

### 基础工具
- `start_pk_session` - 启动专家辩论
- `guru_pk_help` - 获取系统帮助
- `list_available_personas` - 查看所有专家
- `recommend_personas` - 智能推荐专家组合

### 使用示例
```
问题："如何在AI时代保持竞争力？"
专家：["苏格拉底", "埃隆马斯克", "大卫伯恩斯"]
```

### 🌟 推荐组合

**投资决策** - 冯·米塞斯 + 查理·芒格 + 埃隆·马斯克  
**心理成长** - 苏格拉底 + 大卫·伯恩斯 + 克里希那穆提  
**战略决策** - 孙子 + 曾国藩 + 查理·芒格  
**科学理性** - 卡尔·波普尔 + 苏格拉底 + 杰伊·福雷斯特

## 🔄 辩论流程

1. **独立思考** - 每位专家独立分析
2. **交叉辩论** - 互相批评和借鉴  
3. **最终立场** - 形成完善方案
4. **智慧综合** - 融合终极答案

## 🛠️ 技术架构

**语言**: Python 3.10+ | **框架**: MCP | **包管理**: UVX  
**存储**: 本地JSON | **特点**: 零部署、隐私保护

### 项目结构
```
src/guru_pk_mcp/
├── server.py           # MCP服务器
├── personas.py         # 13位专家配置  
├── session_manager.py  # 会话管理
├── custom_personas.py  # 自定义专家
└── models.py          # 数据模型
```

## 🎨 高级功能

### 自定义专家
创建专属思想家角色，定义独特思维特质和语言风格

### 数据管理  
- 自动保存会话到本地JSON
- 支持Markdown导出
- 历史会话查看和恢复
- 完全本地化，保护隐私

### 统计分析
- 会话完成率和活跃度
- 热门专家排行榜  
- 问题领域分析
- 讨论质量统计

## 📱 兼容性

支持所有MCP兼容应用：Claude Desktop、Cursor、TRAE、DeepChat、Cherry Studio等

## 💡 使用提示

- 输入 `guru_pk_help` 获取系统介绍
- 直接提问开始专家辩论  
- 使用 `list_available_personas` 查看专家
- 推荐使用UVX方式安装，零配置依赖管理

## 💭 设计理念

### 灵感来源
本项目受到 [人生教练团Agent](https://mp.weixin.qq.com/s/QGNzRRo7U3Y2fmvOXNJvyw) 的启发。原文提出了多角色PK的创新思路，通常这类系统会使用LangGraph等Agent框架开发，而原作者选择了"飞书MCP"实现更简单的方案，思路巧妙。

### 技术方案对比

**🔧 Agent框架开发**
- ✅ 功能强大，可集成多个LLM API
- ✅ 前端交互灵活，控制性强
- ❌ 开发复杂度高
- ❌ API调用成本高昂

**☁️ 飞书MCP方案**  
- ✅ 几乎零开发，部署简单
- ✅ 利用现有飞书生态
- ❌ 依赖第三方服务
- ❌ 定制化程度有限

**🏠 本地MCP方案（本项目）**
- ✅ 与订阅制Chat APP结合，无API费用
- ✅ 数据本地化，隐私保护
- ✅ 开源可定制，技术独立
- ❌ 依赖MCP客户端实现，兼容性差异
- ❌ 需要一定开发工作

### 核心优势
本项目选择本地MCP方案，在保持"专家PK"、"大神PK"、"人生教练团"这类AI专家辩论系统的核心理念的同时，**最大化成本效益** —— 既避免了高额API费用，又提供了足够的灵活性和隐私保护。
